@@ -27,9 +27,10 @@ def optparseFormat(values):
 
 def getoptFormat(values):
 	'''Format args for getopt '''
-	return [(key, values[key]) for key in values if values[key]]
+	return ([(key, values[key]) for key in values if values[key]], [])
 
 def docoptFormat(values):
+	'''Format args for docopt '''
 	args = {}
 	for key in values:
 		args[key] = values[key] if not (isinstance(values[key], str) and len(values[key]) == 0) else None
